@@ -1,12 +1,11 @@
-//go:build go1.19
-// +build go1.19
+//go:build go1.19 && !go1.20
 
 package quic
 
 import (
 	"crypto/cipher"
 
-	"github.com/marten-seemann/qtls-go1-19"
+	"github.com/quic-go/qtls-go1-19"
 )
 
 type (
